-- Load this file in `nginx.conf`:
--
-- ```
-- server {
--   access_by_lua_file /path/to/do_access.lua;
--   …
-- }
-- ```

local nginx = require("ssso_nginx")

local req_data = nginx.get_request()

if nginx.is(req_data, "/.well-known/webfinger")
  and nginx.has_param(req_data, "rel", "http://openid.net/specs/connect/1.0/issuer")
  and nginx.has_param(req_data, "resource")
then
	-- https://openid.net/specs/openid-connect-discovery-1_0.html
	local oauth2 = require("ssso_oauth2")
	return oauth2.answer_oidc_webfinger(req_data)
end

local conf  = require("ssso_config")
local sess  = require("ssso_sessions")
local sites = require("ssso_sites")

local sso_prefix = conf.get_sso_prefix()
local auth, status = sess.get_session()

if nginx.starts_with(req_data, sso_prefix) then

  -- SSO-specific URL

  if nginx.starts_with(req_data, sso_prefix .. "/login") then
		local login = require("ssso_login")
		return login.answer_request(req_data)
	elseif nginx.starts_with(req_data, sso_prefix .. "/oauth2") then
		local oauth2 = require("ssso_oauth2")
		return oauth2.answer_request(req_data, auth)
	elseif auth then
		local portal = require("ssso_portal")
		return portal.answer_request(req_data, auth)
	else
    return nginx.redirect_to_login(req_data, status)
  end
else

  -- application URL

  return sites.handle_request(req_data, auth)
end
